==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/vi.pl <==
{
  am_pm_abbreviated => [
    "SA",
    "CH",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, 'ng\N{U+00e0}y' d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, dd/MM/y G",
    GyMMMd => "dd MMM, y G",
    GyMd => "dd/MM/y GGGGG",
    H => "HH",
    Hm => "H:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-other" => "'tu\N{U+1ea7}n' W 'c\N{U+1ee7}a' 'th\N{U+00e1}ng' M",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd-MM",
    Md => "dd/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, dd/M/y",
    yMM => "'th\N{U+00e1}ng' MM, y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM, y",
    yMMMM => "MMMM 'n\N{U+0103}m' y",
    yMMMd => "d MMM, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ 'n\N{U+0103}m' y",
    "yw-count-other" => "'tu\N{U+1ea7}n' w 'c\N{U+1ee7}a' 'n\N{U+0103}m' Y",
  },
  code => "vi",
  date_format_full => "EEEE, d MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{0} {1}",
  datetime_format_long => "{0} {1}",
  datetime_format_medium => "{0}, {1}",
  datetime_format_short => "{0}, {1}",
  day_format_abbreviated => [
    "Th 2",
    "Th 3",
    "Th 4",
    "Th 5",
    "Th 6",
    "Th 7",
    "CN",
  ],
  day_format_narrow => [
    "T2",
    "T3",
    "T4",
    "T5",
    "T6",
    "T7",
    "CN",
  ],
  day_format_wide => [
    "Th\N{U+1ee9} Hai",
    "Th\N{U+1ee9} Ba",
    "Th\N{U+1ee9} T\N{U+01b0}",
    "Th\N{U+1ee9} N\N{U+0103}m",
    "Th\N{U+1ee9} S\N{U+00e1}u",
    "Th\N{U+1ee9} B\N{U+1ea3}y",
    "Ch\N{U+1ee7} Nh\N{U+1ead}t",
  ],
  day_stand_alone_abbreviated => [
    "Th 2",
    "Th 3",
    "Th 4",
    "Th 5",
    "Th 6",
    "Th 7",
    "CN",
  ],
  day_stand_alone_narrow => [
    "T2",
    "T3",
    "T4",
    "T5",
    "T6",
    "T7",
    "CN",
  ],
  day_stand_alone_wide => [
    "Th\N{U+1ee9} Hai",
    "Th\N{U+1ee9} Ba",
    "Th\N{U+1ee9} T\N{U+01b0}",
    "Th\N{U+1ee9} N\N{U+0103}m",
    "Th\N{U+1ee9} S\N{U+00e1}u",
    "Th\N{U+1ee9} B\N{U+1ea3}y",
    "Ch\N{U+1ee7} Nh\N{U+1ead}t",
  ],
  era_abbreviated => [
    "Tr\N{U+01b0}\N{U+1edb}c CN",
    "Sau CN",
  ],
  era_narrow => [
    "tr. CN",
    "sau CN",
  ],
  era_wide => [
    "Tr\N{U+01b0}\N{U+1edb}c Thi\N{U+00ea}n Ch\N{U+00fa}a",
    "Sau C\N{U+00f4}ng Nguy\N{U+00ea}n",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Vietnamese",
  month_format_abbreviated => [
    "thg 1",
    "thg 2",
    "thg 3",
    "thg 4",
    "thg 5",
    "thg 6",
    "thg 7",
    "thg 8",
    "thg 9",
    "thg 10",
    "thg 11",
    "thg 12",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "th\N{U+00e1}ng 1",
    "th\N{U+00e1}ng 2",
    "th\N{U+00e1}ng 3",
    "th\N{U+00e1}ng 4",
    "th\N{U+00e1}ng 5",
    "th\N{U+00e1}ng 6",
    "th\N{U+00e1}ng 7",
    "th\N{U+00e1}ng 8",
    "th\N{U+00e1}ng 9",
    "th\N{U+00e1}ng 10",
    "th\N{U+00e1}ng 11",
    "th\N{U+00e1}ng 12",
  ],
  month_stand_alone_abbreviated => [
    "Thg 1",
    "Thg 2",
    "Thg 3",
    "Thg 4",
    "Thg 5",
    "Thg 6",
    "Thg 7",
    "Thg 8",
    "Thg 9",
    "Thg 10",
    "Thg 11",
    "Thg 12",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Th\N{U+00e1}ng 1",
    "Th\N{U+00e1}ng 2",
    "Th\N{U+00e1}ng 3",
    "Th\N{U+00e1}ng 4",
    "Th\N{U+00e1}ng 5",
    "Th\N{U+00e1}ng 6",
    "Th\N{U+00e1}ng 7",
    "Th\N{U+00e1}ng 8",
    "Th\N{U+00e1}ng 9",
    "Th\N{U+00e1}ng 10",
    "Th\N{U+00e1}ng 11",
    "Th\N{U+00e1}ng 12",
  ],
  name => "Vietnamese",
  native_language => "Ti\N{U+1ebf}ng Vi\N{U+1ec7}t",
  native_name => "Ti\N{U+1ebf}ng Vi\N{U+1ec7}t",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Qu\N{U+00fd} 1",
    "Qu\N{U+00fd} 2",
    "Qu\N{U+00fd} 3",
    "Qu\N{U+00fd} 4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "qu\N{U+00fd} 1",
    "qu\N{U+00fd} 2",
    "qu\N{U+00fd} 3",
    "qu\N{U+00fd} 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/vi.pl <==
{
  am_pm_abbreviated => [
    "SA",
    "CH",
  ],
  available_formats => {
    Bh => "h 'gi\N{U+1edd}' B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "h:mm B E",
    EBhms => "h:mm:ss B E",
    EHm => "HH:mm E",
    EHms => "HH:mm:ss E",
    Ed => "E, 'ng\N{U+00e0}y' d",
    Ehm => "h:mm\N{U+202f}a E",
    Ehms => "h:mm:ss\N{U+202f}a E",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM, y G",
    GyMMMd => "d MMM, y G",
    GyMd => "d/M/y G",
    H => "HH 'gi\N{U+1edd}'",
    Hm => "H:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-other" => "'tu\N{U+1ea7}n' W 'c\N{U+1ee7}a' 'th\N{U+00e1}ng' M",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd-MM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMM => "'th\N{U+00e1}ng' MM, y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM, y",
    yMMMM => "MMMM 'n\N{U+0103}m' y",
    yMMMd => "d MMM, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ 'n\N{U+0103}m' y",
    "yw-count-other" => "'tu\N{U+1ea7}n' w 'c\N{U+1ee7}a' 'n\N{U+0103}m' Y",
  },
  code => "vi",
  date_format_full => "EEEE, d MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{0} {1}",
  datetime_format_long => "{0} {1}",
  datetime_format_medium => "{0} {1}",
  datetime_format_short => "{0} {1}",
  day_format_abbreviated => [
    "Th 2",
    "Th 3",
    "Th 4",
    "Th 5",
    "Th 6",
    "Th 7",
    "CN",
  ],
  day_format_narrow => [
    "T2",
    "T3",
    "T4",
    "T5",
    "T6",
    "T7",
    "CN",
  ],
  day_format_wide => [
    "Th\N{U+1ee9} Hai",
    "Th\N{U+1ee9} Ba",
    "Th\N{U+1ee9} T\N{U+01b0}",
    "Th\N{U+1ee9} N\N{U+0103}m",
    "Th\N{U+1ee9} S\N{U+00e1}u",
    "Th\N{U+1ee9} B\N{U+1ea3}y",
    "Ch\N{U+1ee7} Nh\N{U+1ead}t",
  ],
  day_stand_alone_abbreviated => [
    "Th 2",
    "Th 3",
    "Th 4",
    "Th 5",
    "Th 6",
    "Th 7",
    "CN",
  ],
  day_stand_alone_narrow => [
    "T2",
    "T3",
    "T4",
    "T5",
    "T6",
    "T7",
    "CN",
  ],
  day_stand_alone_wide => [
    "Th\N{U+1ee9} Hai",
    "Th\N{U+1ee9} Ba",
    "Th\N{U+1ee9} T\N{U+01b0}",
    "Th\N{U+1ee9} N\N{U+0103}m",
    "Th\N{U+1ee9} S\N{U+00e1}u",
    "Th\N{U+1ee9} B\N{U+1ea3}y",
    "Ch\N{U+1ee7} Nh\N{U+1ead}t",
  ],
  era_abbreviated => [
    "TCN",
    "SCN",
  ],
  era_narrow => [
    "TCN",
    "CN",
  ],
  era_wide => [
    "Tr\N{U+01b0}\N{U+1edb}c Ch\N{U+00fa}a Gi\N{U+00e1}ng Sinh",
    "Sau C\N{U+00f4}ng Nguy\N{U+00ea}n",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Vietnamese",
  month_format_abbreviated => [
    "thg 1",
    "thg 2",
    "thg 3",
    "thg 4",
    "thg 5",
    "thg 6",
    "thg 7",
    "thg 8",
    "thg 9",
    "thg 10",
    "thg 11",
    "thg 12",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "th\N{U+00e1}ng 1",
    "th\N{U+00e1}ng 2",
    "th\N{U+00e1}ng 3",
    "th\N{U+00e1}ng 4",
    "th\N{U+00e1}ng 5",
    "th\N{U+00e1}ng 6",
    "th\N{U+00e1}ng 7",
    "th\N{U+00e1}ng 8",
    "th\N{U+00e1}ng 9",
    "th\N{U+00e1}ng 10",
    "th\N{U+00e1}ng 11",
    "th\N{U+00e1}ng 12",
  ],
  month_stand_alone_abbreviated => [
    "Th\N{U+00e1}ng 1",
    "Th\N{U+00e1}ng 2",
    "Th\N{U+00e1}ng 3",
    "Th\N{U+00e1}ng 4",
    "Th\N{U+00e1}ng 5",
    "Th\N{U+00e1}ng 6",
    "Th\N{U+00e1}ng 7",
    "Th\N{U+00e1}ng 8",
    "Th\N{U+00e1}ng 9",
    "Th\N{U+00e1}ng 10",
    "Th\N{U+00e1}ng 11",
    "Th\N{U+00e1}ng 12",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Th\N{U+00e1}ng 1",
    "Th\N{U+00e1}ng 2",
    "Th\N{U+00e1}ng 3",
    "Th\N{U+00e1}ng 4",
    "Th\N{U+00e1}ng 5",
    "Th\N{U+00e1}ng 6",
    "Th\N{U+00e1}ng 7",
    "Th\N{U+00e1}ng 8",
    "Th\N{U+00e1}ng 9",
    "Th\N{U+00e1}ng 10",
    "Th\N{U+00e1}ng 11",
    "Th\N{U+00e1}ng 12",
  ],
  name => "Vietnamese",
  native_language => "Ti\N{U+1ebf}ng Vi\N{U+1ec7}t",
  native_name => "Ti\N{U+1ebf}ng Vi\N{U+1ec7}t",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Qu\N{U+00fd} 1",
    "Qu\N{U+00fd} 2",
    "Qu\N{U+00fd} 3",
    "Qu\N{U+00fd} 4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "qu\N{U+00fd} 1",
    "qu\N{U+00fd} 2",
    "qu\N{U+00fd} 3",
    "qu\N{U+00fd} 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
